# Edit this configuration file to define what should be installed on
# your system.  Help is available in the configuration.nix(5) man page
# and in the NixOS manual (accessible by running ‘nixos-help’).

{ config, pkgs, ... }:

{
  imports =
    [
      ./hardware-configuration.nix
      ../common-cli.nix
      ../common-gui.nix
    ];

  boot.loader.systemd-boot.enable = true;
  boot.loader.efi.canTouchEfiVariables = true;
  boot.kernelParams = ["acpi_enforce_resources=lax"];
  boot.tmpOnTmpfs = true;

  hardware.bluetooth.enable = true;

  services.udev.packages = with pkgs; [
    usb-modeswitch-data # Logitech G920
  ];

  # Corsair K70
  services.udev.extraRules = ''
    SUBSYSTEM=="usb", ATTR{bInterfaceNumber}=="00", ATTRS{idVendor}=="1b1c", ATTRS{idProduct}=="1b09", RUN+="${pkgs.bash}/bin/sh -c '${pkgs.coreutils}/bin/echo -n %k > /sys''${DEVPATH}/driver/unbind'"
  '';

  networking.hostName = "paul-fixe";

  environment.systemPackages = with pkgs; [
    usb_modeswitch
  ];

  programs.wireshark.enable = true;
  programs.wireshark.package = pkgs.wireshark;

  networking.firewall.enable = false;

  users.users.paul = {
    isNormalUser = true;
    extraGroups = [ "wheel" "networkmanager" "wireshark" "input" ];
    uid = 1000;
  };

  services.syncthing.enable = true;
  services.syncthing.user = "paul";
  services.syncthing.group = "users";

  system.stateVersion = "18.09"; # Did you read the comment?
}
